@@ -8,12 +8,27 @@ import unimatrix.lib.rdbms
 class DatabaseConnection(dict):
     """Represents a database connection configuration."""
 
-    def as_dsn(self):
+    def as_dsn(self, use_async=False):
         """Returns the connection credentials as a data source name."""
         if self['engine'] and self.get('name') == ':memory:':
             return "sqlite://"
         elif self['engine'] == 'sqlite':
             return f"sqlite:///{self['name']}"
+        elif self['engine'] == 'postgresql':
+            scheme = 'postgresql+psycopg2'
+            if use_async:
+                scheme = 'postgresql+asyncpg'
+            dsn = f"{scheme}://"
+            if self.get('username'):
+                dsn += self['username']
+                if self.get('password'):
+                    dsn += f":{self['password']}"
+                dsn += "@"
+            dsn += f"{self.get('host') or 'localhost'}"
+            dsn += f":{self.get('port') or 5432}"
+            if self.get('name'):
+                dsn += f"/{self['name']}"
+            return dsn
         else:
             raise NotImplementedError # pragma: no cover
 
@@ -21,7 +36,8 @@ class DatabaseConnection(dict):
         """Return a :class:`sqlalchemy.engine.Engine` instance configured
         with the connection parameters.
         """
-        return create_engine(self.as_dsn(), *args, **kwargs)
+        return create_engine(self.as_dsn(kwargs.pop('use_async', False)),
+            *args, **kwargs)
 
 
 def load_config(*args, **kwargs):
